@@ -28,15 +28,15 @@ arg_parser = argparse.ArgumentParser(description='Convert pptx to markdown')
 arg_parser.add_argument('pptx_path', help='path to the pptx file to be converted')
 arg_parser.add_argument('-t', '--title', help='path to the custom title list file')
 arg_parser.add_argument('-o', '--output', help='path of the output file')
-arg_parser.add_argument('-i', '--image_dir', help='where to put images extracted')
-arg_parser.add_argument('--image_width', help='maximum image with in px', type=int, default=500)
-arg_parser.add_argument('--disable_image', help='disable image extraction', action="store_true")
-arg_parser.add_argument('--disable_wmf', help='keep wmf formatted image untouched(avoid exceptions under linux)', action="store_true")
-arg_parser.add_argument('--disable_color', help='do not add color HTML tags', action="store_true")
-arg_parser.add_argument('--disable_escaping', help='do not attempt to escape special characters', action="store_true")
+arg_parser.add_argument('-i', '--image-dir', help='where to put images extracted')
+arg_parser.add_argument('--image-width', help='maximum image with in px', type=int)
+arg_parser.add_argument('--disable-image', help='disable image extraction', action="store_true")
+arg_parser.add_argument('--disable-wmf', help='keep wmf formatted image untouched(avoid exceptions under linux)', action="store_true")
+arg_parser.add_argument('--disable-color', help='do not add color HTML tags', action="store_true")
+arg_parser.add_argument('--disable-escaping', help='do not attempt to escape special characters', action="store_true")
 arg_parser.add_argument('--wiki', help='generate output as wikitext(TiddlyWiki)', action="store_true")
 arg_parser.add_argument('--mdk', help='generate output as madoko markdown', action="store_true")
-arg_parser.add_argument('--min_block_size', help='the minimum character number of a text block to be converted', type=int, default=15)
+arg_parser.add_argument('--min-block-size', help='the minimum character number of a text block to be converted', type=int, default=15)
 
 def main():
     args = arg_parser.parse_args()
@@ -58,11 +58,13 @@ def main():
         out_path = args.output
 
     g.out_path = os.path.abspath(out_path)
-    g.img_path = os.path.abspath(os.path.join(out_path, '../img'))
+    g.img_path = os.path.join(out_path, '../img')
 
     if args.image_dir:
         g.img_path = args.image_dir
 
+    g.img_path = os.path.abspath(g.img_path)
+
     if args.image_width:
         g.max_img_width = args.image_width
 
